@@ -116,16 +116,16 @@ TEST_CHANNEL_LIST = {
             "xsg": 3,
         },
         {
-            "c": "400",
+            "c": "105",
             "dvbtriplet": "64511.6400.11075",
             "schedule": True,
             "servicetype": "DSAT",
             "servicetypes": ["DSAT"],
             "sf": "hd",
             "sg": 13,
-            "sid": "75",
+            "sid": "5435",
             "sk": 75,
-            "t": "Sky Arte HD",
+            "t": "Canale 5 HD",
             "xsg": 4,
         },
         {
@@ -141,5 +141,18 @@ TEST_CHANNEL_LIST = {
             "t": "Sky Arte HD",
             "xsg": 1,
         },
+        {
+            "c": "101",
+            "dvbtriplet": "2.2048.10353",
+            "schedule": True,
+            "servicetype": "DSAT",
+            "servicetypes": ["DSAT"],
+            "sf": "sd",
+            "sg": 12,
+            "sid": "2153",
+            "sk": 2153,
+            "t": "BBC One South",
+            "xsg": 3,
+        },
     ],
 }
