@@ -4,7 +4,6 @@ import logging
 import requests
 
 from ..const import RESPONSE_OK
-from ..channel import Channel
 from ..programme import Programme
 
 from .const_gb import CHANNEL_IMAGE_URL, PVR_IMAGE_URL, SCHEDULE_URL, LIVE_IMAGE_URL
@@ -19,34 +18,26 @@ class SkyQCountry:
         """Initialise UK remote."""
         self.channel_image_url = CHANNEL_IMAGE_URL
         self.pvr_image_url = PVR_IMAGE_URL
-        self.epgData = set()
-
-        self._lastEpgUrl = None
         self._host = host
 
     def getEpgData(self, sid, channelno, epgDate):
         """Get EPG data for UK."""
         epgDateStr = epgDate.strftime("%Y%m%d")
+
         epgUrl = SCHEDULE_URL.format(sid, epgDateStr)
         epgData = None
-        if self._lastEpgUrl is None or self._lastEpgUrl != epgUrl:
-            resp = requests.get(epgUrl)
-            if resp.status_code == RESPONSE_OK:
-                epgData = resp.json()["schedule"]
-                self._lastEpgUrl = epgUrl
-        else:
-            return self.epgData
+        programmes = set()
+
+        resp = requests.get(epgUrl)
+        if resp.status_code == RESPONSE_OK:
+            epgData = resp.json()["schedule"]
 
         if epgData is None:
-            return None
+            return programmes
 
-        if len(epgData[0]["events"]) == 0:
-            _LOGGER.warning(
-                f"W0010UK - Programme data not found. Do you need to set 'live_tv' to False? {self._host}"
-            )
-            return None
+        if len(epgData) == 0:
+            return programmes
 
-        programmes = set()
         for p in epgData[0]["events"]:
             starttime = datetime.utcfromtimestamp(p["st"])
             endtime = datetime.utcfromtimestamp(p["st"] + p["d"])
@@ -69,5 +60,5 @@ class SkyQCountry:
                 programmeuuid, starttime, endtime, title, season, episode, imageUrl
             )
             programmes.add(programme)
-        self.epgData = Channel(sid, channelno, None, None, sorted(programmes))
-        return self.epgData
+
+        return programmes
