@@ -4,7 +4,6 @@ import logging
 import requests
 
 from ..const import RESPONSE_OK
-from ..channel import Channel
 from ..programme import Programme
 
 from .const_it import (
@@ -25,9 +24,6 @@ class SkyQCountry:
         """Initialise Italy remote."""
         self.channel_image_url = CHANNEL_IMAGE_URL
         self.pvr_image_url = PVR_IMAGE_URL
-        self.epgData = set()
-
-        self._lastEpgUrl = None
         self._host = host
         self._channellist = None
 
@@ -43,25 +39,20 @@ class SkyQCountry:
             if str(channel["number"]) == str(channelno):
                 cid = channel["id"]
 
-        epgData = None
         epgUrl = SCHEDULE_URL.format(cid, queryDateFrom, queryDateTo)
-        if self._lastEpgUrl is None or self._lastEpgUrl != epgUrl:
-            resp = requests.get(epgUrl)
-            if resp.status_code == RESPONSE_OK:
-                epgData = resp.json()["events"]
-                self._lastEpgUrl = epgUrl
-        else:
-            return self.epgData
+        epgData = None
+        programmes = set()
+
+        resp = requests.get(epgUrl)
+        if resp.status_code == RESPONSE_OK:
+            epgData = resp.json()["events"]
 
         if epgData is None:
-            return None
+            return programmes
+
         if len(epgData) == 0:
-            _LOGGER.warning(
-                f"W0010IT - Programme data not found. Do you need to set 'live_tv' to False? {self._host}"
-            )
-            return None
+            return programmes
 
-        programmes = set()
         epgDataLen = len(epgData) - 1
         for index, p in enumerate(epgData):
             starttime = datetime.strptime(p["starttime"], "%Y-%m-%dT%H:%M:%SZ")
@@ -89,8 +80,8 @@ class SkyQCountry:
                 programmeuuid, starttime, endtime, title, season, episode, imageUrl
             )
             programmes.add(programme)
-        self.epgData = Channel(sid, channelno, None, None, sorted(programmes))
-        return self.epgData
+
+        return programmes
 
     def _getChannels(self):
         resp = requests.get(CHANNEL_URL)
