@@ -49,6 +49,7 @@ from .const import (
     APP_EPG,
 )
 from .const import TEST_CHANNEL_LIST
+from .channel import Channel
 from .programme import RecordedProgramme
 from .media import Media
 
@@ -70,7 +71,9 @@ class SkyQRemote:
         self._jsonport = jsonport
         self._overrideCountry = overrideCountry
         self.deviceSetup = False
+        self.channel = None
         self._soapControlURL = None
+        self._lastEpg = None
 
         self.powerStatus()
         if not self.deviceSetup:
@@ -182,15 +185,37 @@ class SkyQRemote:
         else:
             return None
 
-    def getEpgData(self, sid, epgDate):
-        """Get EPG data for the specified channel."""
-        channelno = self._getChannelNode(sid)["channelno"]
-        channelname = self._getChannelNode(sid)["channel"]
+    def getEpgData(self, sid, epgDate, days=2):
+        """Get EPG data for the specified channel/date."""
+        channelNode = self._getChannelNode(sid)
+        channelno = channelNode["channelno"]
+        channelname = channelNode["channel"]
         channelImageUrl = self._buildChannelUrl(sid, channelname)
-        channel = self._remoteCountry.getEpgData(sid, channelno, epgDate)
-        channel.channelname = channelname
-        channel.channelImageUrl = channelImageUrl
-        return channel
+
+        epg = str(sid) + epgDate.strftime("%Y%m%d")
+        if self._lastEpg == epg:
+            return self.channel
+
+        programmes = set()
+        for n in range(days):
+            programmesData = self._remoteCountry.getEpgData(
+                sid, channelno, epgDate + timedelta(days=n)
+            )
+            if len(programmesData) > 0:
+                programmes = programmes.union(programmesData)
+            else:
+                break
+
+        self._lastEpg = epg
+
+        if len(programmes) == 0:
+            _LOGGER.info(f"I0020 - Programme data not found for {sid} : {epgDate}")
+
+        self.channel = Channel(
+            sid, channelno, channelname, channelImageUrl, sorted(programmes)
+        )
+
+        return self.channel
 
     def getProgrammeFromEpgJSON(self, sid, epgDate, queryDate):
         """Get programme from EPG for specfied time and channel as json."""
@@ -203,7 +228,7 @@ class SkyQRemote:
     def getProgrammeFromEpg(self, sid, epgDate, queryDate):
         """Get programme from EPG for specfied time and channel."""
         epgData = self.getEpgData(sid, epgDate)
-        if epgData is None:
+        if len(epgData.programmes) == 0:
             return None
 
         try:
@@ -232,10 +257,7 @@ class SkyQRemote:
             programme = self.getProgrammeFromEpg(sid, queryDate, queryDate)
             if programme is None:
                 return None
-            if programme == PAST_END_OF_EPG:
-                programme = self.getProgrammeFromEpg(
-                    sid, queryDate + timedelta(days=1), queryDate
-                )
+
             return programme
         except Exception as err:
             _LOGGER.exception(f"X0030 - Error occurred: {self._host} : {sid} : {err}")
@@ -256,8 +278,16 @@ class SkyQRemote:
         starttime = None
         endtime = None
         programmeuuid = None
+        channel = None
+        imageUrl = None
+        title = None
 
-        recording = self._http_json(REST_RECORDING_DETAILS.format(pvrId))["details"]
+        resp = self._http_json(REST_RECORDING_DETAILS.format(pvrId))
+        if "details" not in resp:
+            _LOGGER.info(f"I0030 - Recording data not found for {pvrId}")
+            return None
+
+        recording = resp["details"]
 
         channel = recording["cn"]
         title = recording["t"]
@@ -289,20 +319,16 @@ class SkyQRemote:
         """Issue the specified sequence of commands to SkyQ box."""
         if isinstance(sequence, list):
             for item in sequence:
-                if item not in self.commands:
-                    _LOGGER.error(
-                        "E0010 - Invalid command: {self._host} : {0}".format(item)
-                    )
+                if item.casefold() not in self.commands:
+                    _LOGGER.error(f"E0010 - Invalid command: {self._host} : {item}")
                     break
                 self._sendCommand(self.commands[item.casefold()])
                 time.sleep(0.5)
         else:
             if sequence not in self.commands:
-                _LOGGER.error(
-                    "E0020 - Invalid command: {self._host} : {0}".format(sequence)
-                )
+                _LOGGER.error(f"E0020 - Invalid command: {self._host} : {sequence}")
             else:
-                self._sendCommand(self.commands[sequence])
+                self._sendCommand(self.commands[sequence.casefold()])
 
     def _http_json(self, path, headers=None) -> str:
         response = requests.get(
